/*
 * Module code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 32 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qlocation.sip"
#include <qlocation.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeocodereply.sip"
#include <qgeocodereply.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeoaddress.sip"
#include <qgeoaddress.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroutereply.sip"
#include <qgeoroutereply.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroute.sip"
#include <qgeoroute.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacereply.sip"
#include <qplacereply.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacedetailsreply.sip"
#include <qplacedetailsreply.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontentreply.sip"
#include <qplacecontentreply.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontentrequest.sip"
#include <qplacecontentrequest.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchreply.sip"
#include <qplacesearchreply.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchrequest.sip"
#include <qplacesearchrequest.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchsuggestionreply.sip"
#include <qplacesearchsuggestionreply.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceidreply.sip"
#include <qplaceidreply.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplace.sip"
#include <qplace.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecategory.sip"
#include <qplacecategory.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceicon.sip"
#include <qplaceicon.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacematchreply.sip"
#include <qplacematchreply.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacematchrequest.sip"
#include <qplacematchrequest.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeomaneuver.sip"
#include <qgeomaneuver.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 73 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroute.sip"
#include <qgeoroute.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 152 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroutesegment.sip"
#include <qgeoroutesegment.h>
#line 155 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 158 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 161 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 167 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 170 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qlocation.sip"
#include <qlocation.h>
#line 173 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceattribute.sip"
#include <qplaceattribute.h>
#line 176 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontactdetail.sip"
#include <qplacecontactdetail.h>
#line 179 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontent.sip"
#include <qplacecontent.h>
#line 182 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceeditorial.sip"
#include <qplaceeditorial.h>
#line 185 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceimage.sip"
#include <qplaceimage.h>
#line 188 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchresult.sip"
#include <qplacesearchresult.h>
#line 191 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceproposedsearchresult.sip"
#include <qplaceproposedsearchresult.h>
#line 194 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceratings.sip"
#include <qplaceratings.h>
#line 197 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceresult.sip"
#include <qplaceresult.h>
#line 200 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacereview.sip"
#include <qplacereview.h>
#line 203 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesupplier.sip"
#include <qplacesupplier.h>
#line 206 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceuser.sip"
#include <qplaceuser.h>
#line 209 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtLocation[] = {
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'G', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'G', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'R', 'o', 'u', 't', 'e', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'T', 'y', 'p', 'e', '>', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', ':', ':', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'R', 'o', 'u', 't', 'e', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'P', 'l', 'a', 'c', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', ':', ':', 'I', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'P', 'l', 'a', 'c', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'R', 'e', 'l', 'e', 'v', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 's', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 'D', 'e', 't', 'a', 'i', 'l', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'D', 'e', 't', 'a', 'i', 'l', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'T', 'y', 'p', 'e', 's', 0,
    's', 'e', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'R', 'o', 'u', 't', 'e', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 's', 0,
    'M', 'i', 's', 's', 'i', 'n', 'g', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'T', 'r', 'a', 'v', 'e', 'l', 'M', 'o', 'd', 'e', 's', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'T', 'r', 'a', 'v', 'e', 'l', 'M', 'o', 'd', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'I', 'd', 'R', 'e', 'p', 'l', 'y', ':', ':', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'I', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 0,
    'P', 'l', 'a', 'c', 'e', 'R', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 't', 'i', 'o', 'n', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'S', 'u', 'g', 'g', 'e', 's', 't', 'i', 'o', 'n', 'R', 'e', 'p', 'l', 'y', 0,
    's', 'e', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'R', 'o', 'u', 't', 'e', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 's', 0,
    'E', 'x', 'c', 'l', 'u', 'd', 'e', 'A', 'r', 'e', 'a', 's', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'l', 'a', 'c', 'e', 'C', 'o', 'n', 't', 'a', 'c', 't', 'D', 'e', 't', 'a', 'i', 'l', '>', 0,
    'Q', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', ':', ':', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 'c', 'o', 'p', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'P', 'r', 'o', 'p', 'o', 's', 'e', 'd', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', 0,
    's', 'e', 't', 'N', 'u', 'm', 'b', 'e', 'r', 'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'R', 'o', 'u', 't', 'e', 's', 0,
    's', 'e', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 's', 0,
    's', 'e', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'D', 'o', 'e', 's', 'N', 'o', 't', 'E', 'x', 'i', 's', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'L', 'o', 'c', 'a', 'l', 'i', 'z', 'e', 'd', 'G', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'l', 'a', 'c', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', '>', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 's', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'I', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 0,
    'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'R', 'o', 'u', 't', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'O', 'f', 'f', 'l', 'i', 'n', 'e', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'S', 'e', 'a', 'r', 'c', 'h', 'S', 'u', 'g', 'g', 'e', 's', 't', 'i', 'o', 'n', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'T', 'y', 'p', 'e', 's', 0,
    's', 'e', 't', 'T', 'i', 'm', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'I', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    'L', 'o', 'c', 'a', 'l', 'i', 'z', 'e', 'd', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'L', 'o', 'c', 'a', 'l', 'i', 'z', 'e', 'd', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'O', 'f', 'f', 'l', 'i', 'n', 'e', 'G', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'O', 'n', 'l', 'i', 'n', 'e', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'C', 'o', 'd', 'i', 'n', 'g', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'M', 'a', 'p', '<', 'i', 'n', 't', ',', 'Q', 'P', 'l', 'a', 'c', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', '>', 0,
    'R', 'e', 'v', 'e', 'r', 's', 'e', 'G', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'n', 'u', 'm', 'b', 'e', 'r', 'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'R', 'o', 'u', 't', 'e', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'E', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 'e', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'T', 'r', 'a', 'v', 'e', 'l', 'M', 'o', 'd', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    'L', 'o', 'c', 'a', 'l', 'i', 'z', 'e', 'd', 'P', 'l', 'a', 'c', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'O', 'n', 'l', 'i', 'n', 'e', 'G', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'P', 'l', 'a', 'c', 'e', 'D', 'o', 'e', 's', 'N', 'o', 't', 'E', 'x', 'i', 's', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'O', 'p', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'e', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 's', 0,
    's', 'e', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'P', 'a', 'g', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'A', 'n', 'y', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'D', 'i', 's', 'a', 'l', 'l', 'o', 'w', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'O', 'f', 'f', 'l', 'i', 'n', 'e', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'O', 'f', 'f', 'l', 'i', 'n', 'e', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'p', 'l', 'y', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'l', 'a', 'c', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', '>', 0,
    'Q', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', ':', ':', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'R', 'e', 'm', 'o', 'v', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'n', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 'e', 't', 'E', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'T', 'y', 'p', 'e', 's', 0,
    't', 'i', 'm', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'I', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 0,
    'A', 'n', 'y', 'G', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'L', 'e', 'x', 'i', 'c', 'a', 'l', 'P', 'l', 'a', 'c', 'e', 'N', 'a', 'm', 'e', 'H', 'i', 'n', 't', 0,
    'M', 'o', 't', 'o', 'r', 'P', 'o', 'o', 'l', 'L', 'a', 'n', 'e', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'N', 'e', 'u', 't', 'r', 'a', 'l', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'N', 'o', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'O', 'f', 'f', 'l', 'i', 'n', 'e', 'P', 'l', 'a', 'c', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'O', 'n', 'l', 'i', 'n', 'e', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'O', 'n', 'l', 'i', 'n', 'e', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'P', 'l', 'a', 'c', 'e', 'M', 'a', 't', 'c', 'h', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'P', 'u', 'b', 'l', 'i', 'c', 'T', 'r', 'a', 'n', 's', 'i', 't', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'C', 'o', 'd', 'e', 'R', 'e', 'p', 'l', 'y', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'G', 'e', 'o', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', '>', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'R', 'e', 'q', 'u', 'i', 'r', 'e', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'g', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'E', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'n', 't', 'a', 'c', 't', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    's', 'e', 't', 'A', 'l', 'l', 'o', 'w', 'E', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'a', 'l', 0,
    's', 'e', 't', 'E', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 'e', 't', 'F', 'i', 'r', 's', 't', 'R', 'o', 'u', 't', 'e', 'S', 'e', 'g', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'M', 'e', 'a', 's', 'u', 'r', 'e', 'm', 'e', 'n', 't', 'S', 'y', 's', 't', 'e', 'm', 0,
    's', 'e', 't', 'R', 'o', 'u', 't', 'e', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'T', 'o', 't', 'a', 'l', 'C', 'o', 'n', 't', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'W', 'a', 'y', 'p', 'o', 'i', 'n', 't', 's', 'M', 'e', 't', 'a', 'd', 'a', 't', 'a', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'T', 'r', 'a', 'v', 'e', 'l', 'M', 'o', 'd', 'e', 's', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'L', 'i', 'g', 'h', 't', 'R', 'i', 'g', 'h', 't', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'U', 'T', 'u', 'r', 'n', 'R', 'i', 'g', 'h', 't', 0,
    'N', 'o', 'G', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'O', 'n', 'l', 'i', 'n', 'e', 'P', 'l', 'a', 'c', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'P', 'u', 'b', 'l', 'i', 'c', 'T', 'r', 'a', 'n', 's', 'i', 't', 'T', 'r', 'a', 'v', 'e', 'l', 0,
    'Q', 'G', 'e', 'o', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'G', 'e', 'o', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'L', 'e', 'g', '>', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'C', 'o', 'n', 't', 'a', 'c', 't', 'D', 'e', 't', 'a', 'i', 'l', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'R', 'o', 'u', 't', 'e', 'U', 'p', 'd', 'a', 't', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'S', 'a', 'v', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'C', 'o', 'n', 't', 'a', 'c', 't', 'D', 'e', 't', 'a', 'i', 'l', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'P', 'a', 'g', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    's', 'e', 't', 'N', 'e', 'x', 't', 'R', 'o', 'u', 't', 'e', 'S', 'e', 'g', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'R', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 't', 'i', 'o', 'n', 'I', 'd', 0,
    'A', 'n', 'y', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'A', 'n', 'y', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'A', 'v', 'o', 'i', 'd', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'C', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'B', 'e', 'a', 'r', 'R', 'i', 'g', 'h', 't', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'H', 'a', 'r', 'd', 'R', 'i', 'g', 'h', 't', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'L', 'i', 'g', 'h', 't', 'L', 'e', 'f', 't', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'U', 'T', 'u', 'r', 'n', 'L', 'e', 'f', 't', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'V', 'a', 'r', 'i', 'a', 'n', 't', 'M', 'a', 'p', '>', 0,
    'Q', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 'R', 'e', 'p', 'l', 'y', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'D', 'e', 't', 'a', 'i', 'l', 's', 'R', 'e', 'p', 'l', 'y', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'M', 'a', 't', 'c', 'h', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'R', 'e', 'p', 'l', 'y', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', 0,
    'R', 'e', 'm', 'o', 'v', 'e', 'P', 'l', 'a', 'c', 'e', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'e', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    'm', 'a', 'p', 'p', 'i', 'n', 'g', 'E', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'n', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'r', 'o', 'u', 't', 'i', 'n', 'g', 'E', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 'e', 't', 'E', 'x', 't', 'r', 'a', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    's', 'e', 't', 'I', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'N', 'e', 'x', 't', 'P', 'a', 'g', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 'c', 'o', 'p', 'e', 0,
    'A', 'n', 'y', 'P', 'l', 'a', 'c', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'B', 'e', 'a', 'r', 'L', 'e', 'f', 't', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'H', 'a', 'r', 'd', 'L', 'e', 'f', 't', 0,
    'E', 'n', 'g', 'i', 'n', 'e', 'N', 'o', 't', 'S', 'e', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'M', 'o', 's', 't', 'E', 'c', 'o', 'n', 'o', 'm', 'i', 'c', 'R', 'o', 'u', 't', 'e', 0,
    'N', 'o', 'M', 'a', 'p', 'p', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'N', 'o', 'R', 'o', 'u', 't', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'N', 'o', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'r', 'i', 'v', 'a', 't', 'e', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'Q', 'G', 'e', 'o', 'C', 'o', 'd', 'i', 'n', 'g', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'R', 'e', 'p', 'l', 'y', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 'p', 'l', 'y', 0,
    'a', 'l', 'l', 'o', 'w', 'E', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'a', 'l', 0,
    'e', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'f', 'i', 'r', 's', 't', 'R', 'o', 'u', 't', 'e', 'S', 'e', 'g', 'm', 'e', 'n', 't', 0,
    'g', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'm', 'e', 'a', 's', 'u', 'r', 'e', 'm', 'e', 'n', 't', 'S', 'y', 's', 't', 'e', 'm', 0,
    'n', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'p', 'l', 'a', 'c', 'e', 's', 'E', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'r', 'o', 'u', 't', 'e', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'S', 'u', 'g', 'g', 'e', 's', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'a', 'c', 't', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'e', 't', 'D', 'e', 't', 'a', 'i', 'l', 's', 'F', 'e', 't', 'c', 'h', 'e', 'd', 0,
    's', 'e', 't', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 'D', 'e', 't', 'a', 'i', 'l', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    't', 'o', 't', 'a', 'l', 'C', 'o', 'n', 't', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    'w', 'a', 'y', 'p', 'o', 'i', 'n', 't', 's', 'M', 'e', 't', 'a', 'd', 'a', 't', 'a', 0,
    'B', 'a', 'd', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'B', 'a', 's', 'i', 'c', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'D', 'a', 't', 'a', 0,
    'C', 'o', 'm', 'b', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'D', 'e', 'v', 'i', 'c', 'e', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'N', 'o', 'P', 'l', 'a', 'c', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'P', 'e', 'd', 'e', 's', 't', 'r', 'i', 'a', 'n', 'T', 'r', 'a', 'v', 'e', 'l', 0,
    'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'u', 'b', 'l', 'i', 'c', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'S', 'e', 'g', 'm', 'e', 'n', 't', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', '>', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'M', 'a', 't', 'c', 'h', 'R', 'e', 'p', 'l', 'y', 0,
    'S', 'a', 'v', 'e', 'P', 'l', 'a', 'c', 'e', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'c', 'h', 'i', 'l', 'd', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'I', 'd', 's', 0,
    'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'I', 'c', 'o', 'n', 'U', 'r', 'l', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'g', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'i', 's', 'L', 'e', 'g', 'L', 'a', 's', 't', 'S', 'e', 'g', 'm', 'e', 'n', 't', 0,
    'n', 'e', 'x', 't', 'R', 'o', 'u', 't', 'e', 'S', 'e', 'g', 'm', 'e', 'n', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'I', 'd', 0,
    'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 't', 'i', 'o', 'n', 'I', 'd', 0,
    's', 'e', 't', 'D', 'e', 'p', 'a', 'r', 't', 'u', 'r', 'e', 'T', 'i', 'm', 'e', 0,
    's', 'e', 't', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'R', 'e', 'l', 'e', 'v', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'S', 'e', 'a', 'r', 'c', 'h', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'e', 't', 'S', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    's', 'e', 't', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'D', 'e', 't', 'a', 'i', 'l', 0,
    'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'D', 'i', 'r', 't', 'R', 'o', 'a', 'd', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'M', 'o', 's', 't', 'S', 'c', 'e', 'n', 'i', 'c', 'R', 'o', 'u', 't', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'E', 'd', 'i', 't', 'o', 'r', 'i', 'a', 'l', 0,
    'U', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', 'H', 'i', 'n', 't', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'U', 'p', 'd', 'a', 't', 'e', 'd', 0,
    'c', 'h', 'i', 'l', 'd', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'e', 'P', 'l', 'a', 'c', 'e', 0,
    'e', 'x', 't', 'r', 'a', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    'g', 'e', 't', 'P', 'l', 'a', 'c', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'g', 'e', 't', 'P', 'l', 'a', 'c', 'e', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    'i', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 'T', 'e', 'x', 't', 0,
    'm', 'a', 'p', 'p', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'n', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'n', 'e', 'x', 't', 'P', 'a', 'g', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'r', 'o', 'u', 't', 'i', 'n', 'g', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    's', 'e', 't', 'E', 'x', 'c', 'l', 'u', 'd', 'e', 'A', 'r', 'e', 'a', 's', 0,
    's', 'e', 't', 'O', 'v', 'e', 'r', 'a', 'l', 'l', 'R', 'o', 'u', 't', 'e', 0,
    'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 'c', 'o', 'p', 'e', 0,
    'B', 'a', 's', 'i', 'c', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 's', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'R', 'i', 'g', 'h', 't', 0,
    'H', 'i', 'g', 'h', 'w', 'a', 'y', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'R', 'e', 'p', 'l', 'y', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'S', 'u', 'p', 'p', 'l', 'i', 'e', 'r', 0,
    'R', 'e', 'm', 'o', 'v', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'T', 'r', 'a', 'f', 'f', 'i', 'c', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', 'R', 'o', 'u', 't', 'e', 0,
    'c', 'o', 'n', 't', 'a', 'c', 't', 'D', 'e', 't', 'a', 'i', 'l', 's', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'U', 'p', 'd', 'a', 't', 'e', 'd', 0,
    'd', 'e', 't', 'a', 'i', 'l', 's', 'F', 'e', 't', 'c', 'h', 'e', 'd', 0,
    'g', 'e', 'o', 'c', 'o', 'd', 'i', 'n', 'g', 'E', 'r', 'r', 'o', 'r', 0,
    'm', 'a', 'n', 'a', 'g', 'e', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'm', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 'D', 'e', 't', 'a', 'i', 'l', 0,
    'm', 'a', 't', 'c', 'h', 'i', 'n', 'g', 'P', 'l', 'a', 'c', 'e', 's', 0,
    'p', 'l', 'a', 'c', 'e', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'W', 'e', 'b', 's', 'i', 't', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'r', 'e', 'v', 'e', 'r', 's', 'e', 'G', 'e', 'o', 'c', 'o', 'd', 'e', 0,
    'r', 'o', 'u', 't', 'i', 'n', 'g', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'S', 'u', 'g', 'g', 'e', 's', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'T', 'r', 'a', 'v', 'e', 'l', 'M', 'o', 'd', 'e', 's', 0,
    'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'I', 'd', 0,
    'B', 'i', 'c', 'y', 'c', 'l', 'e', 'T', 'r', 'a', 'v', 'e', 'l', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'L', 'e', 'f', 't', 0,
    'E', 'd', 'i', 't', 'o', 'r', 'i', 'a', 'l', 'T', 'y', 'p', 'e', 0,
    'N', 'o', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'D', 'a', 't', 'a', 0,
    'Q', 'G', 'e', 'o', 'C', 'o', 'd', 'e', 'R', 'e', 'p', 'l', 'y', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'l', 'a', 'c', 'e', '>', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'I', 'd', 'R', 'e', 'p', 'l', 'y', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'R', 'a', 't', 'i', 'n', 'g', 's', 0,
    'S', 'h', 'o', 'r', 't', 'e', 's', 't', 'R', 'o', 'u', 't', 'e', 0,
    'T', 'u', 'n', 'n', 'e', 'l', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'A', 'd', 'd', 'e', 'd', 0,
    'd', 'e', 'p', 'a', 'r', 't', 'u', 'r', 'e', 'T', 'i', 'm', 'e', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 'l', 'e', 'v', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    's', 'e', 'g', 'm', 'e', 'n', 't', 'D', 'e', 't', 'a', 'i', 'l', 0,
    's', 'e', 't', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'I', 'd', 0,
    's', 'e', 't', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    's', 'e', 't', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'r', 'e', 'a', 0,
    's', 'e', 't', 'S', 'e', 'a', 'r', 'c', 'h', 'T', 'e', 'r', 'm', 0,
    's', 'e', 't', 'S', 'u', 'p', 'p', 'l', 'i', 'e', 'r', 'I', 'd', 0,
    's', 'e', 't', 'T', 'o', 't', 'a', 'l', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'T', 'r', 'a', 'v', 'e', 'l', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'T', 'r', 'a', 'v', 'e', 'l', 'T', 'i', 'm', 'e', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    'F', 'a', 's', 't', 'e', 's', 't', 'R', 'o', 'u', 't', 'e', 0,
    'F', 'e', 'r', 'r', 'y', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'O', 'p', 'e', 'n', 'i', 'n', 'g', 'H', 'o', 'u', 'r', 's', 0,
    'P', 'a', 'r', 'k', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 'L', 'e', 'g', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'R', 'e', 's', 'u', 'l', 't', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'R', 'e', 'v', 'i', 'e', 'w', 0,
    'S', 'a', 'v', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'c', 'o', 'n', 't', 'a', 'c', 't', 'T', 'y', 'p', 'e', 's', 0,
    'e', 'x', 'c', 'l', 'u', 'd', 'e', 'A', 'r', 'e', 'a', 's', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 'T', 'y', 'p', 'e', 's', 0,
    'm', 'a', 'p', 'p', 'i', 'n', 'g', 'E', 'r', 'r', 'o', 'r', 0,
    'o', 'v', 'e', 'r', 'a', 'l', 'l', 'R', 'o', 'u', 't', 'e', 0,
    'p', 'l', 'a', 'c', 'e', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'p', 'l', 'a', 'c', 'e', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'p', 'l', 'a', 'c', 'e', 'U', 'p', 'd', 'a', 't', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'E', 'm', 'a', 'i', 'l', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'P', 'h', 'o', 'n', 'e', 0,
    'r', 'o', 'u', 't', 'i', 'n', 'g', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'a', 'v', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    's', 'e', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'R', 'o', 'u', 't', 'e', 'L', 'e', 'g', 's', 0,
    's', 'e', 't', 'S', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', 0,
    's', 'e', 't', 'W', 'a', 'y', 'p', 'o', 'i', 'n', 't', 's', 0,
    'C', 'a', 'n', 'c', 'e', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'L', 'o', 'a', 'd', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'o', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'N', 'o', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 's', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'R', 'e', 'p', 'l', 'y', 0,
    'R', 'e', 'm', 'o', 'v', 'e', 'P', 'l', 'a', 'c', 'e', 0,
    'T', 'o', 'l', 'l', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'T', 'r', 'u', 'c', 'k', 'T', 'r', 'a', 'v', 'e', 'l', 0,
    'a', 'd', 'd', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'i', 's', 'S', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', 0,
    'm', 'a', 'n', 'a', 'g', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'p', 'l', 'a', 'c', 'e', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'P', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    's', 'e', 't', 'D', 'a', 't', 'e', 'T', 'i', 'm', 'e', 0,
    's', 'e', 't', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    's', 'e', 't', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    's', 'e', 't', 'L', 'e', 'g', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 0,
    's', 'e', 't', 'M', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'R', 'e', 'v', 'i', 'e', 'w', 'I', 'd', 0,
    's', 'e', 't', 'S', 'u', 'p', 'p', 'l', 'i', 'e', 'r', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    's', 'e', 't', 'W', 'a', 'y', 'p', 'o', 'i', 'n', 't', 0,
    's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'o', 'n', 's', 0,
    't', 'r', 'a', 'v', 'e', 'l', 'M', 'o', 'd', 'e', 's', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'R', 'o', 'u', 't', 'e', 0,
    'C', 'u', 's', 't', 'o', 'm', 'T', 'y', 'p', 'e', 0,
    'P', 'a', 'r', 's', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'I', 'c', 'o', 'n', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 'U', 's', 'e', 'r', 0,
    'R', 'e', 'v', 'i', 'e', 'w', 'T', 'y', 'p', 'e', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'I', 'd', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    'p', 'l', 'a', 'c', 'e', 'A', 'd', 'd', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'F', 'a', 'x', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'A', 'r', 'e', 'a', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'T', 'e', 'r', 'm', 0,
    's', 'e', 't', 'A', 'v', 'e', 'r', 'a', 'g', 'e', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    's', 'e', 't', 'I', 'm', 'a', 'g', 'e', 'I', 'd', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'e', 's', 0,
    's', 'e', 't', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 0,
    's', 'e', 't', 'P', 'l', 'a', 'c', 'e', 'I', 'd', 0,
    's', 'e', 't', 'R', 'a', 't', 'i', 'n', 'g', 's', 0,
    's', 'e', 't', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    's', 'e', 't', 'R', 'e', 's', 'u', 'l', 't', 's', 0,
    's', 'e', 't', 'R', 'o', 'u', 't', 'e', 'I', 'd', 0,
    's', 'u', 'p', 'p', 'l', 'i', 'e', 'r', 'I', 'd', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 't', 'a', 'l', 'C', 'o', 'u', 'n', 't', 0,
    't', 'r', 'a', 'v', 'e', 'l', 'M', 'o', 'd', 'e', 0,
    't', 'r', 'a', 'v', 'e', 'l', 'T', 'i', 'm', 'e', 0,
    'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'C', 'a', 'r', 'T', 'r', 'a', 'v', 'e', 'l', 0,
    'I', 'm', 'a', 'g', 'e', 'T', 'y', 'p', 'e', 0,
    'N', 'o', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'G', 'e', 'o', 'R', 'o', 'u', 't', 'e', 0,
    'Q', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'a', 'v', 'e', 'P', 'l', 'a', 'c', 'e', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'U', 'r', 'l', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'a', 'd', 'd', 'R', 'o', 'u', 't', 'e', 's', 0,
    'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', 0,
    'r', 'o', 'u', 't', 'e', 'L', 'e', 'g', 's', 0,
    's', 'a', 'v', 'e', 'P', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'B', 'o', 'u', 'n', 'd', 's', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'e', 0,
    's', 'e', 't', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'e', 't', 'P', 'l', 'a', 'c', 'e', 's', 0,
    's', 'e', 't', 'R', 'a', 't', 'i', 'n', 'g', 0,
    's', 'e', 't', 'R', 'o', 'u', 't', 'e', 's', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'I', 'd', 0,
    'w', 'a', 'y', 'p', 'o', 'i', 'n', 't', 's', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'd', 'a', 't', 'e', 'T', 'i', 'm', 'e', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'l', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    'l', 'e', 'g', 'I', 'n', 'd', 'e', 'x', 0,
    'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'm', 'a', 'n', 'e', 'u', 'v', 'e', 'r', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'I', 'd', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'r', 'e', 'v', 'i', 'e', 'w', 'I', 'd', 0,
    's', 'e', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 0,
    's', 'e', 't', 'L', 'i', 'm', 'i', 't', 0,
    's', 'e', 't', 'P', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'u', 'p', 'p', 'l', 'i', 'e', 'r', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    'w', 'a', 'y', 'p', 'o', 'i', 'n', 't', 0,
    'N', 'o', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'a', 'y', 'm', 'e', 'n', 't', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'a', 'b', 'o', 'r', 't', 'e', 'd', 0,
    'a', 'v', 'e', 'r', 'a', 'g', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 0,
    'g', 'e', 'o', 'c', 'o', 'd', 'e', 0,
    'i', 'm', 'a', 'g', 'e', 'I', 'd', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 's', 0,
    'm', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 0,
    'p', 'l', 'a', 'c', 'e', 'I', 'd', 0,
    'r', 'a', 't', 'i', 'n', 'g', 's', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 0,
    'r', 'e', 's', 'u', 'l', 't', 's', 0,
    'r', 'o', 'u', 't', 'e', 'I', 'd', 0,
    's', 'e', 't', 'I', 'c', 'o', 'n', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 0,
    'N', 'o', 'T', 'y', 'p', 'e', 0,
    'Q', 'P', 'l', 'a', 'c', 'e', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'b', 'o', 'u', 'n', 'd', 's', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 0,
    'o', 'f', 'f', 's', 'e', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'p', 'l', 'a', 'c', 'e', 's', 0,
    'r', 'a', 't', 'i', 'n', 'g', 0,
    'r', 'o', 'u', 't', 'e', 's', 0,
    's', 'e', 'a', 'r', 'c', 'h', 0,
    's', 'e', 't', 'U', 'r', 'l', 0,
    'u', 's', 'e', 'r', 'I', 'd', 0,
    'a', 'b', 'o', 'r', 't', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'l', 'a', 'b', 'e', 'l', 0,
    'l', 'i', 'm', 'i', 't', 0,
    'p', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'I', 'd', 0,
    't', 'i', 't', 'l', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'i', 'c', 'o', 'n', 0,
    'n', 'a', 'm', 'e', 0,
    'p', 'a', 't', 'h', 0,
    's', 'i', 'z', 'e', 0,
    't', 'y', 'p', 'e', 0,
    'u', 's', 'e', 'r', 0,
    'u', 'r', 'l', 0,
};

::QPlaceMatchReply* sipVH_QtLocation_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPlaceMatchRequest& a0)
{
    ::QPlaceMatchReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPlaceMatchRequest(a0), sipType_QPlaceMatchRequest, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPlaceMatchReply, &sipRes);

    return sipRes;
}

::QPlace sipVH_QtLocation_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPlace& a0)
{
    ::QPlace sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPlace(a0), sipType_QPlace, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPlace, &sipRes);

    return sipRes;
}

::QUrl sipVH_QtLocation_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPlaceIcon& a0, const ::QSize& a1)
{
    ::QUrl sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QPlaceIcon(a0), sipType_QPlaceIcon, SIP_NULLPTR, new ::QSize(a1), sipType_QSize, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QUrl, &sipRes);

    return sipRes;
}

void sipVH_QtLocation_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const QList< ::QLocale>& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new QList< ::QLocale>(a0), sipType_QList_0100QLocale, SIP_NULLPTR);
}

QList< ::QLocale> sipVH_QtLocation_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QList< ::QLocale> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QLocale, &sipRes);

    return sipRes;
}

QList< ::QPlaceCategory> sipVH_QtLocation_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    QList< ::QPlaceCategory> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QPlaceCategory, &sipRes);

    return sipRes;
}

::QPlaceCategory sipVH_QtLocation_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QPlaceCategory sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPlaceCategory, &sipRes);

    return sipRes;
}

::QStringList sipVH_QtLocation_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

::QString sipVH_QtLocation_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

::QPlaceReply* sipVH_QtLocation_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPlaceReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPlaceReply, &sipRes);

    return sipRes;
}

::QPlaceIdReply* sipVH_QtLocation_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPlaceCategory& a0, const ::QString& a1)
{
    ::QPlaceIdReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QPlaceCategory(a0), sipType_QPlaceCategory, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPlaceIdReply, &sipRes);

    return sipRes;
}

::QPlaceIdReply* sipVH_QtLocation_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QPlaceIdReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPlaceIdReply, &sipRes);

    return sipRes;
}

::QPlaceIdReply* sipVH_QtLocation_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPlace& a0)
{
    ::QPlaceIdReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPlace(a0), sipType_QPlace, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPlaceIdReply, &sipRes);

    return sipRes;
}

::QPlaceSearchSuggestionReply* sipVH_QtLocation_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPlaceSearchRequest& a0)
{
    ::QPlaceSearchSuggestionReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPlaceSearchRequest(a0), sipType_QPlaceSearchRequest, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPlaceSearchSuggestionReply, &sipRes);

    return sipRes;
}

::QPlaceSearchReply* sipVH_QtLocation_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPlaceSearchRequest& a0)
{
    ::QPlaceSearchReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPlaceSearchRequest(a0), sipType_QPlaceSearchRequest, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPlaceSearchReply, &sipRes);

    return sipRes;
}

::QPlaceContentReply* sipVH_QtLocation_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPlaceContentRequest& a0)
{
    ::QPlaceContentReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QPlaceContentRequest(a0), sipType_QPlaceContentRequest, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPlaceContentReply, &sipRes);

    return sipRes;
}

::QPlaceDetailsReply* sipVH_QtLocation_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QPlaceDetailsReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPlaceDetailsReply, &sipRes);

    return sipRes;
}

::QPlaceReply::Type sipVH_QtLocation_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPlaceReply::Type sipRes = ::QPlaceReply::Reply;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QPlaceReply_Type, &sipRes);

    return sipRes;
}

::QGeoRouteReply* sipVH_QtLocation_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QGeoRoute& a0, const ::QGeoCoordinate& a1)
{
    ::QGeoRouteReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QGeoRoute(a0), sipType_QGeoRoute, SIP_NULLPTR, new ::QGeoCoordinate(a1), sipType_QGeoCoordinate, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QGeoRouteReply, &sipRes);

    return sipRes;
}

::QGeoRouteReply* sipVH_QtLocation_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QGeoRouteRequest& a0)
{
    ::QGeoRouteReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QGeoRouteRequest(a0), sipType_QGeoRouteRequest, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QGeoRouteReply, &sipRes);

    return sipRes;
}

::QGeoCodeReply* sipVH_QtLocation_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QGeoCoordinate& a0, const ::QGeoShape& a1)
{
    ::QGeoCodeReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QGeoCoordinate(a0), sipType_QGeoCoordinate, SIP_NULLPTR, new ::QGeoShape(a1), sipType_QGeoShape, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QGeoCodeReply, &sipRes);

    return sipRes;
}

::QGeoCodeReply* sipVH_QtLocation_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, int a1, int a2, const ::QGeoShape& a3)
{
    ::QGeoCodeReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiiN", new ::QString(a0), sipType_QString, SIP_NULLPTR, a1, a2, new ::QGeoShape(a3), sipType_QGeoShape, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QGeoCodeReply, &sipRes);

    return sipRes;
}

::QGeoCodeReply* sipVH_QtLocation_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QGeoAddress& a0, const ::QGeoShape& a1)
{
    ::QGeoCodeReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QGeoAddress(a0), sipType_QGeoAddress, SIP_NULLPTR, new ::QGeoShape(a1), sipType_QGeoShape, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QGeoCodeReply, &sipRes);

    return sipRes;
}

void sipVH_QtLocation_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_QtLocation_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtLocation_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtLocation_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtLocation_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtLocation_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtLocation_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QGeoServiceProvider(void **);}
static const sipTypeDef *sipSubClass_QGeoServiceProvider(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 35 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QGeoCodingManager, &sipType_QGeoCodingManager, -1, 1},
        {sipName_QGeoRoutingManagerEngine, &sipType_QGeoRoutingManagerEngine, -1, 2},
        {sipName_QGeoCodeReply, &sipType_QGeoCodeReply, -1, 3},
        {sipName_QPlaceReply, &sipType_QPlaceReply, 10, 4},
        {sipName_QPlaceManagerEngine, &sipType_QPlaceManagerEngine, -1, 5},
        {sipName_QGeoRoutingManager, &sipType_QGeoRoutingManager, -1, 6},
        {sipName_QGeoCodingManagerEngine, &sipType_QGeoCodingManagerEngine, -1, 7},
        {sipName_QGeoServiceProvider, &sipType_QGeoServiceProvider, -1, 8},
        {sipName_QGeoRouteReply, &sipType_QGeoRouteReply, -1, 9},
        {sipName_QPlaceManager, &sipType_QPlaceManager, -1, -1},
        {sipName_QPlaceSearchSuggestionReply, &sipType_QPlaceSearchSuggestionReply, -1, 11},
        {sipName_QPlaceMatchReply, &sipType_QPlaceMatchReply, -1, 12},
        {sipName_QPlaceDetailsReply, &sipType_QPlaceDetailsReply, -1, 13},
        {sipName_QPlaceContentReply, &sipType_QPlaceContentReply, -1, 14},
        {sipName_QPlaceSearchReply, &sipType_QPlaceSearchReply, -1, 15},
        {sipName_QPlaceIdReply, &sipType_QPlaceIdReply, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 1031 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationcmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_QLocation_Visibility___or__(PyObject *, PyObject *);}
static PyObject *slot_QLocation_Visibility___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocation::Visibility a0;
        ::QLocation::VisibilityScope* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QLocation_Visibility, &a0, sipType_QLocation_VisibilityScope, &a1, &a1State))
        {
            ::QLocation::VisibilityScope*sipRes;

            sipRes = new ::QLocation::VisibilityScope((a0 | *a1));
            sipReleaseType(a1, sipType_QLocation_VisibilityScope, a1State);

            return sipConvertFromNewType(sipRes, sipType_QLocation_VisibilityScope, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QLocation_Visibility[] = {
    {(void *)slot_QLocation_Visibility___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoServiceProvider_NavigationFeature___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_NavigationFeature___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoServiceProvider::NavigationFeature a0;
        ::QGeoServiceProvider::NavigationFeatures* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoServiceProvider_NavigationFeature, &a0, sipType_QGeoServiceProvider_NavigationFeatures, &a1, &a1State))
        {
            ::QGeoServiceProvider::NavigationFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::NavigationFeatures((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoServiceProvider_NavigationFeatures, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_NavigationFeatures, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoServiceProvider_NavigationFeature[] = {
    {(void *)slot_QGeoServiceProvider_NavigationFeature___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeature___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeature___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoServiceProvider::PlacesFeature a0;
        ::QGeoServiceProvider::PlacesFeatures* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoServiceProvider_PlacesFeature, &a0, sipType_QGeoServiceProvider_PlacesFeatures, &a1, &a1State))
        {
            ::QGeoServiceProvider::PlacesFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::PlacesFeatures((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoServiceProvider_PlacesFeatures, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_PlacesFeatures, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoServiceProvider_PlacesFeature[] = {
    {(void *)slot_QGeoServiceProvider_PlacesFeature___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoServiceProvider_MappingFeature___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_MappingFeature___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoServiceProvider::MappingFeature a0;
        ::QGeoServiceProvider::MappingFeatures* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoServiceProvider_MappingFeature, &a0, sipType_QGeoServiceProvider_MappingFeatures, &a1, &a1State))
        {
            ::QGeoServiceProvider::MappingFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::MappingFeatures((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoServiceProvider_MappingFeatures, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_MappingFeatures, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoServiceProvider_MappingFeature[] = {
    {(void *)slot_QGeoServiceProvider_MappingFeature___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoServiceProvider_GeocodingFeature___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_GeocodingFeature___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoServiceProvider::GeocodingFeature a0;
        ::QGeoServiceProvider::GeocodingFeatures* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoServiceProvider_GeocodingFeature, &a0, sipType_QGeoServiceProvider_GeocodingFeatures, &a1, &a1State))
        {
            ::QGeoServiceProvider::GeocodingFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::GeocodingFeatures((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoServiceProvider_GeocodingFeatures, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_GeocodingFeatures, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoServiceProvider_GeocodingFeature[] = {
    {(void *)slot_QGeoServiceProvider_GeocodingFeature___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoServiceProvider_RoutingFeature___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_RoutingFeature___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoServiceProvider::RoutingFeature a0;
        ::QGeoServiceProvider::RoutingFeatures* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoServiceProvider_RoutingFeature, &a0, sipType_QGeoServiceProvider_RoutingFeatures, &a1, &a1State))
        {
            ::QGeoServiceProvider::RoutingFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::RoutingFeatures((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoServiceProvider_RoutingFeatures, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_RoutingFeatures, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoServiceProvider_RoutingFeature[] = {
    {(void *)slot_QGeoServiceProvider_RoutingFeature___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoRouteRequest_ManeuverDetail___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRouteRequest_ManeuverDetail___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::ManeuverDetail a0;
        ::QGeoRouteRequest::ManeuverDetails* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoRouteRequest_ManeuverDetail, &a0, sipType_QGeoRouteRequest_ManeuverDetails, &a1, &a1State))
        {
            ::QGeoRouteRequest::ManeuverDetails*sipRes;

            sipRes = new ::QGeoRouteRequest::ManeuverDetails((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoRouteRequest_ManeuverDetails, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_ManeuverDetails, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoRouteRequest_ManeuverDetail[] = {
    {(void *)slot_QGeoRouteRequest_ManeuverDetail___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoRouteRequest_SegmentDetail___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRouteRequest_SegmentDetail___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::SegmentDetail a0;
        ::QGeoRouteRequest::SegmentDetails* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoRouteRequest_SegmentDetail, &a0, sipType_QGeoRouteRequest_SegmentDetails, &a1, &a1State))
        {
            ::QGeoRouteRequest::SegmentDetails*sipRes;

            sipRes = new ::QGeoRouteRequest::SegmentDetails((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoRouteRequest_SegmentDetails, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_SegmentDetails, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoRouteRequest_SegmentDetail[] = {
    {(void *)slot_QGeoRouteRequest_SegmentDetail___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoRouteRequest_RouteOptimization___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRouteRequest_RouteOptimization___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::RouteOptimization a0;
        ::QGeoRouteRequest::RouteOptimizations* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoRouteRequest_RouteOptimization, &a0, sipType_QGeoRouteRequest_RouteOptimizations, &a1, &a1State))
        {
            ::QGeoRouteRequest::RouteOptimizations*sipRes;

            sipRes = new ::QGeoRouteRequest::RouteOptimizations((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoRouteRequest_RouteOptimizations, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_RouteOptimizations, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoRouteRequest_RouteOptimization[] = {
    {(void *)slot_QGeoRouteRequest_RouteOptimization___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoRouteRequest_FeatureWeight___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRouteRequest_FeatureWeight___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::FeatureWeight a0;
        ::QGeoRouteRequest::FeatureWeights* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoRouteRequest_FeatureWeight, &a0, sipType_QGeoRouteRequest_FeatureWeights, &a1, &a1State))
        {
            ::QGeoRouteRequest::FeatureWeights*sipRes;

            sipRes = new ::QGeoRouteRequest::FeatureWeights((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoRouteRequest_FeatureWeights, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_FeatureWeights, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoRouteRequest_FeatureWeight[] = {
    {(void *)slot_QGeoRouteRequest_FeatureWeight___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoRouteRequest_FeatureType___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRouteRequest_FeatureType___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::FeatureType a0;
        ::QGeoRouteRequest::FeatureTypes* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoRouteRequest_FeatureType, &a0, sipType_QGeoRouteRequest_FeatureTypes, &a1, &a1State))
        {
            ::QGeoRouteRequest::FeatureTypes*sipRes;

            sipRes = new ::QGeoRouteRequest::FeatureTypes((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoRouteRequest_FeatureTypes, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_FeatureTypes, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoRouteRequest_FeatureType[] = {
    {(void *)slot_QGeoRouteRequest_FeatureType___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QGeoRouteRequest_TravelMode___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRouteRequest_TravelMode___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::TravelMode a0;
        ::QGeoRouteRequest::TravelModes* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QGeoRouteRequest_TravelMode, &a0, sipType_QGeoRouteRequest_TravelModes, &a1, &a1State))
        {
            ::QGeoRouteRequest::TravelModes*sipRes;

            sipRes = new ::QGeoRouteRequest::TravelModes((a0 | *a1));
            sipReleaseType(a1, sipType_QGeoRouteRequest_TravelModes, a1State);

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_TravelModes, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QGeoRouteRequest_TravelMode[] = {
    {(void *)slot_QGeoRouteRequest_TravelMode___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoCodeReply__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 0, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoManeuver__InstructionDirection, SIP_NULLPTR, 0}, sipNameNr_InstructionDirection, 4, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoRouteReply__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoRouteRequest__FeatureType, SIP_NULLPTR, 0}, sipNameNr_FeatureType, 10, slots_QGeoRouteRequest_FeatureType},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoRouteRequest__FeatureWeight, SIP_NULLPTR, 0}, sipNameNr_FeatureWeight, 10, slots_QGeoRouteRequest_FeatureWeight},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoRouteRequest__ManeuverDetail, SIP_NULLPTR, 0}, sipNameNr_ManeuverDetail, 10, slots_QGeoRouteRequest_ManeuverDetail},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoRouteRequest__RouteOptimization, SIP_NULLPTR, 0}, sipNameNr_RouteOptimization, 10, slots_QGeoRouteRequest_RouteOptimization},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoRouteRequest__SegmentDetail, SIP_NULLPTR, 0}, sipNameNr_SegmentDetail, 10, slots_QGeoRouteRequest_SegmentDetail},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoRouteRequest__TravelMode, SIP_NULLPTR, 0}, sipNameNr_TravelMode, 10, slots_QGeoRouteRequest_TravelMode},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoServiceProvider__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 26, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoServiceProvider__GeocodingFeature, SIP_NULLPTR, 0}, sipNameNr_GeocodingFeature, 26, slots_QGeoServiceProvider_GeocodingFeature},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoServiceProvider__MappingFeature, SIP_NULLPTR, 0}, sipNameNr_MappingFeature, 26, slots_QGeoServiceProvider_MappingFeature},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoServiceProvider__NavigationFeature, SIP_NULLPTR, 0}, sipNameNr_NavigationFeature, 26, slots_QGeoServiceProvider_NavigationFeature},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoServiceProvider__PlacesFeature, SIP_NULLPTR, 0}, sipNameNr_PlacesFeature, 26, slots_QGeoServiceProvider_PlacesFeature},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QGeoServiceProvider__RoutingFeature, SIP_NULLPTR, 0}, sipNameNr_RoutingFeature, 26, slots_QGeoServiceProvider_RoutingFeature},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QLocation__Visibility, SIP_NULLPTR, 0}, sipNameNr_Visibility, 48, slots_QLocation_Visibility},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPlaceContent__Type, SIP_NULLPTR, 0}, sipNameNr_Type, 57, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPlaceIdReply__OperationType, SIP_NULLPTR, 0}, sipNameNr_OperationType, 64, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPlaceReply__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 73, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPlaceReply__Type, SIP_NULLPTR, 0}, sipNameNr_Type, 73, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPlaceSearchRequest__RelevanceHint, SIP_NULLPTR, 0}, sipNameNr_RelevanceHint, 79, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPlaceSearchResult__SearchResultType, SIP_NULLPTR, 0}, sipNameNr_SearchResultType, 81, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtLocation[] = {
    &sipTypeDef_QtLocation_QGeoCodeReply.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtLocation_QGeoCodingManager.ctd_base,
    &sipTypeDef_QtLocation_QGeoCodingManagerEngine.ctd_base,
    &sipTypeDef_QtLocation_QGeoManeuver.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtLocation_QGeoRoute.ctd_base,
    &sipTypeDef_QtLocation_QGeoRouteLeg.ctd_base,
    &sipTypeDef_QtLocation_QGeoRouteReply.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtLocation_QGeoRouteRequest.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtLocation_QGeoRouteRequest_FeatureTypes.ctd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtLocation_QGeoRouteRequest_FeatureWeights.ctd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_QtLocation_QGeoRouteRequest_ManeuverDetails.ctd_base,
    &enumTypes[6].etd_base,
    &sipTypeDef_QtLocation_QGeoRouteRequest_RouteOptimizations.ctd_base,
    &enumTypes[7].etd_base,
    &sipTypeDef_QtLocation_QGeoRouteRequest_SegmentDetails.ctd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtLocation_QGeoRouteRequest_TravelModes.ctd_base,
    &sipTypeDef_QtLocation_QGeoRouteSegment.ctd_base,
    &sipTypeDef_QtLocation_QGeoRoutingManager.ctd_base,
    &sipTypeDef_QtLocation_QGeoRoutingManagerEngine.ctd_base,
    &sipTypeDef_QtLocation_QGeoServiceProvider.ctd_base,
    &enumTypes[9].etd_base,
    &enumTypes[10].etd_base,
    &sipTypeDef_QtLocation_QGeoServiceProvider_GeocodingFeatures.ctd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_QtLocation_QGeoServiceProvider_MappingFeatures.ctd_base,
    &enumTypes[12].etd_base,
    &sipTypeDef_QtLocation_QGeoServiceProvider_NavigationFeatures.ctd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_QtLocation_QGeoServiceProvider_PlacesFeatures.ctd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_QtLocation_QGeoServiceProvider_RoutingFeatures.ctd_base,
    &sipTypeDef_QtLocation_QList_0100QGeoLocation.mtd_base,
    &sipTypeDef_QtLocation_QList_0100QGeoRectangle.mtd_base,
    &sipTypeDef_QtLocation_QList_0100QGeoRoute.mtd_base,
    &sipTypeDef_QtLocation_QList_0100QGeoRouteLeg.mtd_base,
    &sipTypeDef_QtLocation_QList_0100QGeoRouteRequest_FeatureType.mtd_base,
    &sipTypeDef_QtLocation_QList_0100QPlace.mtd_base,
    &sipTypeDef_QtLocation_QList_0100QPlaceCategory.mtd_base,
    &sipTypeDef_QtLocation_QList_0100QPlaceContactDetail.mtd_base,
    &sipTypeDef_QtLocation_QList_0100QPlaceSearchResult.mtd_base,
    &sipTypeDef_QtLocation_QList_0100QVariantMap.mtd_base,
    &sipTypeDef_QtLocation_QLocation.ctd_base,
    &enumTypes[15].etd_base,
    &sipTypeDef_QtLocation_QLocation_VisibilityScope.ctd_base,
    &sipTypeDef_QtLocation_QMap_1800_0100QPlaceContent.mtd_base,
    &sipTypeDef_QtLocation_QNavigationManager.ctd_base,
    &sipTypeDef_QtLocation_QPlace.ctd_base,
    &sipTypeDef_QtLocation_QPlaceAttribute.ctd_base,
    &sipTypeDef_QtLocation_QPlaceCategory.ctd_base,
    &sipTypeDef_QtLocation_QPlaceContactDetail.ctd_base,
    &sipTypeDef_QtLocation_QPlaceContent.ctd_base,
    &enumTypes[16].etd_base,
    &sipTypeDef_QtLocation_QPlaceContentReply.ctd_base,
    &sipTypeDef_QtLocation_QPlaceContentRequest.ctd_base,
    &sipTypeDef_QtLocation_QPlaceDetailsReply.ctd_base,
    &sipTypeDef_QtLocation_QPlaceEditorial.ctd_base,
    &sipTypeDef_QtLocation_QPlaceIcon.ctd_base,
    &sipTypeDef_QtLocation_QPlaceIdReply.ctd_base,
    &enumTypes[17].etd_base,
    &sipTypeDef_QtLocation_QPlaceImage.ctd_base,
    &sipTypeDef_QtLocation_QPlaceManager.ctd_base,
    &sipTypeDef_QtLocation_QPlaceManagerEngine.ctd_base,
    &sipTypeDef_QtLocation_QPlaceMatchReply.ctd_base,
    &sipTypeDef_QtLocation_QPlaceMatchRequest.ctd_base,
    &sipTypeDef_QtLocation_QPlaceProposedSearchResult.ctd_base,
    &sipTypeDef_QtLocation_QPlaceRatings.ctd_base,
    &sipTypeDef_QtLocation_QPlaceReply.ctd_base,
    &enumTypes[18].etd_base,
    &enumTypes[19].etd_base,
    &sipTypeDef_QtLocation_QPlaceResult.ctd_base,
    &sipTypeDef_QtLocation_QPlaceReview.ctd_base,
    &sipTypeDef_QtLocation_QPlaceSearchReply.ctd_base,
    &sipTypeDef_QtLocation_QPlaceSearchRequest.ctd_base,
    &enumTypes[20].etd_base,
    &sipTypeDef_QtLocation_QPlaceSearchResult.ctd_base,
    &enumTypes[21].etd_base,
    &sipTypeDef_QtLocation_QPlaceSearchSuggestionReply.ctd_base,
    &sipTypeDef_QtLocation_QPlaceSupplier.ctd_base,
    &sipTypeDef_QtLocation_QPlaceUser.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QPlaceContent::Collection", "QMap<int, QPlaceContent>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtLocation_QtCore[] = {
    {"QChildEvent"},
    {"QDateTime"},
    {"QEvent"},
    {"QList<QLocale>"},
    {"QLocale"},
    {"QLocale::MeasurementSystem"},
    {"QMetaMethod"},
    {"QObject"},
    {"QSize"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {"QVariantMap"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtLocation_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtPositioning. */
sipImportedTypeDef sipImportedTypes_QtLocation_QtPositioning[] = {
    {"QGeoAddress"},
    {"QGeoCoordinate"},
    {"QGeoLocation"},
    {"QGeoRectangle"},
    {"QGeoShape"},
    {"QList<QGeoCoordinate>"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtLocation_QtCore, sipImportedVirtErrorHandlers_QtLocation_QtCore, SIP_NULLPTR},
    {"PyQt5.QtPositioning", sipImportedTypes_QtLocation_QtPositioning, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QGeoServiceProvider, {7, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtLocation = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtLocation,
    0,
    sipStrings_QtLocation,
    importsTable,
    SIP_NULLPTR,
    86,
    sipExportedTypes_QtLocation,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    1,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtLocation;

sip_qt_metaobject_func sip_QtLocation_qt_metaobject;
sip_qt_metacall_func sip_QtLocation_qt_metacall;
sip_qt_metacast_func sip_QtLocation_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtLocation()
#else
PyMODINIT_FUNC PyInit_QtLocation()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtLocation",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtLocation = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtLocation == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtLocation, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtLocation_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtLocation_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtLocation_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtLocation_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtLocation, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
